@@ -3,11 +3,9 @@ use in_toto::crypto::{KeyType, PrivateKey, SignatureScheme};
 use rebuilderd_common::api::Client;
 use rebuilderd_common::config::ConfigFile;
 use rebuilderd_common::errors::*;
+use rebuilderd_common::utils;
 use std::fs;
-use std::fs::OpenOptions;
-use std::io::prelude::*;
 use std::io::ErrorKind;
-use std::os::unix::fs::OpenOptionsExt;
 use std::path::Path;
 
 pub struct Profile {
@@ -46,26 +44,12 @@ pub fn load() -> Result<Profile> {
 }
 
 fn load_key<P: AsRef<Path>>(path: P) -> Result<Profile> {
-    let path = path.as_ref();
+    let privkey = utils::load_or_create(path.as_ref(), || {
+        PrivateKey::new(KeyType::Ed25519).map_err(Error::from)
+    })?;
 
-    let privkey = if path.exists() {
-        let content = fs::read(path)?;
-        PrivateKey::from_pkcs8(&content, SignatureScheme::Ed25519)?
-    } else {
-        let sk = PrivateKey::new(KeyType::Ed25519)?;
-
-        let mut file = OpenOptions::new()
-            .mode(0o640)
-            .write(true)
-            .create(true)
-            .open(path)?;
-        file.write_all(&sk[..])?;
-
-        PrivateKey::from_pkcs8(&sk, SignatureScheme::Ed25519)?
-    };
-
-    let pk = privkey.public();
-    let pubkey = BASE64.encode(pk.as_bytes());
+    let privkey = PrivateKey::from_pkcs8(&privkey, SignatureScheme::Ed25519)?;
+    let pubkey = BASE64.encode(privkey.public().as_bytes());
 
     Ok(Profile { pubkey, privkey })
 }
